{% if app_notification.notification.priority == priorities.LOW %}
    {% include 'django_spire/badge/secondary_badge.html' with badge_text='Low' %}
{% elif app_notification.notification.priority == priorities.MEDIUM %}
    {% include 'django_spire/badge/warning_badge.html' with badge_text='Med' %}
{% elif app_notification.notification.priority == priorities.HIGH %}
    {% include 'django_spire/badge/danger_badge.html' with badge_text='High' %}
{% endif %}
