.side-panel {
    background: var(--app-layer-one);
    border-color: var(--app-primary);
    height: var(--app-side-panel-height);
    top: var(--app-top-navigation-height);
}

.panel-toggle-container {
    cursor: pointer;
    height: calc(100dvh - var(--app-top-navigation-height));
    top: var(--app-top-navigation-height);
    width: 16px;
    z-index: 1030;
}

.panel-toggle-container::before {
    display: none;
}

.panel-toggle-container .bi {
    background: var(--app-layer-one);
    border: 1px solid var(--app-primary);
    color: var(--app-primary);
    font-size: 1rem;
    padding: 1px 3px;
    z-index: 1;
}

.panel-toggle-container:hover .bi {
    background: var(--app-primary);
    color: var(--app-layer-one);
}

.panel-toggle-container-left {
    left: 0.25rem;
}

.panel-toggle-container-right {
    right: 0;
}

.ps-panel-offset {
    padding-left: 1.5rem;
}

.pe-panel-offset {
    padding-right: 1.5rem;
}

@media (min-width: 992px) {
    .panel-toggle-container-left {
        left: var(--app-side-navigation-width);
    }
}

@media (max-width: 991px) {
    .mobile-hide {
        display: none !important;
    }

    .panel-toggle-container {
        margin: 0px 1px;
    }

    .panel-toggle-container-left {
        left: 0;
    }

    .panel-toggle-container-right {
        right: 0;
    }

    .ps-panel-offset {
        padding-left: 2.0rem;
    }

    .pe-panel-offset {
        padding-right: 2.0rem;
    }

    .side-panel-left,
    .side-panel-right {
        border: none;
    }
}
