<div class="row {% block container_outer_class %}{% endblock %}">
    <div class="col-12">
        {% block container_header_content %}
            <div class="row justify-content-between align-items-end px-md-3 py-2">
                <div class="col">
                    <h1 class="{% block container_title_class %}fs-1 fw-semi-bold{% endblock %}">
                        {% block container_title %}
                        {% endblock %}
                    </h1>
                </div>

                <div class="col-auto">
                    {% block container_button %}
                    {% endblock %}
                </div>
            </div>
        {% endblock %}

        {% block container_filter_section %}
        {% endblock %}

        <div class="row {% block container_class %}{% endblock %}">
            <div class="col-12 {% block container_content_class %}{% endblock %}">
                {% block container_content %}
                {% endblock %}
            </div>
        </div>
    </div>
</div>
