<div
    class="d-flex justify-content-start px-3 py-2"
    data-message-chat-id="{{ chat_id }}"
    {% if not is_loading %}
        x-data="{
            show_message: false,

            init() {
                setTimeout(() => this.show_message = true, 300)
                setTimeout(() => $el.scrollIntoView({behavior: 'smooth'}), 350)
            }
        }"
        x-show="show_message"
        x-transition
    {% endif %}
>
    {% include message_intel.template with content_class="bg-app-layer-two text-app-default-text-color" bubble_shape="chat-bubble-response" avatar_icon="bi-robot" avatar_class="bg-app-primary-soft text-app-primary" %}
</div>
