{% extends 'django_spire/page/full_page.html' %}

{% block page_content %}
    <div class="row">
        <div class="col">
            {% include 'demo/card/demo_file_version_list_container.html' with queryset=file_list %}
        </div>
    </div>
{% endblock %}
